pub struct Builder { /* private fields */ }Expand description
A Bundle builder.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub async fn exchanges_from_dir(self, dir: impl AsRef<Path>) -> Result<Self>
pub async fn exchanges_from_dir(self, dir: impl AsRef<Path>) -> Result<Self>
Append exchanges from files rooted at the given directory.
One exchange is created for each file, however, two exchanges
are created for index.html file, as follows:
- The pareent directory serves the contents of
index.htmlfile. - The URL for
index.htmlfile is a redirect to the parent directory (301MOVED PERMANENTLY).
Examples
use webbundle::{Bundle, Version};
let bundle = Bundle::builder()
.version(Version::VersionB2)
.exchanges_from_dir("build").await?
.build()?;Sourcepub fn exchanges_from_dir_sync(self, dir: impl AsRef<Path>) -> Result<Self>
pub fn exchanges_from_dir_sync(self, dir: impl AsRef<Path>) -> Result<Self>
Sync version of exchanges_from_dir.