pub struct Bundle { /* private fields */ }
Represents a WebBundle.

Implementations

Gets the version.

Gets the primary url.

Gets the exchanges.

Parses the given bytes and returns the parsed Bundle.

Encodes this bundle and write the result to the given write.

Encodes this bundle.

Returns a new builder.